<?php
/**
 * Welcome
 *
 * @package Dhor
 */

use Nilambar\Welcome\Welcome;

add_action(
	'wp_welcome_init',
	function() {
		$obj = new Welcome( 'theme', 'dhor' );

		$obj->set_page(
			array(
				'menu_title'  => esc_html__( 'About Dhor', 'dhor' ),
				'menu_slug'   => 'about-dhor',
				'parent_page' => 'themes.php',
			)
		);

		$obj->set_admin_notice(
			array(
				'screens' => array( 'themes', 'dashboard' ),
			)
		);

		$obj->set_quick_links(
			array(
				array(
					'text' => esc_html__( 'View Demos', 'dhor' ),
					'url'  => 'https://dandure.com/dhor/',
					'type' => 'primary',
				),
				array(
					'text' => esc_html__( 'Theme Homepage', 'dhor' ),
					'url'  => 'https://wphait.com/themes/dhor/',
					'type' => 'secondary',
				),
			)
		);

		$obj->add_tab(
			array(
				'id'    => 'getting-started',
				'title' => esc_html__( 'Getting Started', 'dhor' ),
				'type'  => 'grid',
				'items' => array(
					array(
						'title'       => esc_html__( 'Customize Everything', 'dhor' ),
						'icon'        => 'dashicons dashicons-admin-customizer',
						'description' => esc_html__( 'Theme uses Customizer API for theme options. Start customizing every aspect of the website with customizer.', 'dhor' ),
						'button_text' => esc_html__( 'Go to Customizer', 'dhor' ),
						'button_url'  => wp_customize_url(),
						'button_type' => 'primary',
					),
					array(
						'title'       => esc_html__( 'Get Support', 'dhor' ),
						'icon'        => 'dashicons dashicons-editor-help',
						'description' => esc_html__( 'Got theme support question or found bug or got some feedbacks? Please visit support forum in the WordPress.org directory.', 'dhor' ),
						'button_text' => esc_html__( 'Visit Support', 'dhor' ),
						'button_url'  => 'https://wordpress.org/support/theme/dhor/#new-post',
						'button_type' => 'secondary',
						'is_new_tab'  => true,
					),
					array(
						'title'       => esc_html__( 'Documentation', 'dhor' ),
						'icon'        => 'dashicons dashicons-admin-page',
						'description' => 'Kindly check our theme documentation for detailed information and instructions.',
						'button_text' => esc_html__( 'View Documentation', 'dhor' ),
						'button_url'  => 'https://dandure.com/documentation/dhor/',
						'button_type' => 'secondary',
						'is_new_tab'  => true,
					),
					array(
						'title'       => esc_html__( 'Child Theme', 'dhor' ),
						'icon'        => 'dashicons dashicons-admin-appearance',
						'description' => 'Want to customize theme file? Please use a child theme.',
						'button_text' => esc_html__( 'About Child Theme', 'dhor' ),
						'button_url'  => 'https://developer.wordpress.org/themes/advanced-topics/child-themes/',
						'button_type' => 'secondary',
						'is_new_tab'  => true,
					),
				),
			)
		);

		$obj->add_tab(
			array(
				'id'    => 'plugins',
				'title' => esc_html__( 'Recommended Plugins', 'dhor' ),
				'type'  => 'plugin',
				'items' => array(
					array(
						'name'        => esc_html__( 'WooCommerce Product Tabs', 'dhor' ),
						'description' => esc_html__( 'Plugin to add new tabs for WooCommerce products.', 'dhor' ),
						'slug'        => 'woocommerce-product-tabs',
					),
					array(
						'name'        => esc_html__( 'Admin Customizer', 'dhor' ),
						'description' => esc_html__( 'Customize admin interface of your WordPress site.', 'dhor' ),
						'slug'        => 'admin-customizer',
					),
					array(
						'name'        => esc_html__( 'Advanced Google reCAPTCHA', 'dhor' ),
						'description' => esc_html__( 'Protect your WordPress website against spam comments and brute-force attacks using Google reCAPTCHA.', 'dhor' ),
						'slug'        => 'advanced-google-recaptcha',
					),
					array(
						'name'        => esc_html__( 'Coming Soon & Maintenance Mode Page', 'dhor' ),
						'description' => esc_html__( 'Simple and easy to setup Coming soon, Under Construction and Maintenance page plugin.', 'dhor' ),
						'slug'        => 'nifty-coming-soon-and-under-construction-page',
					),
					array(
						'name'        => esc_html__( 'Post Grid Elementor Addon', 'dhor' ),
						'description' => esc_html__( 'Elementor page builder addon to display posts in a grid.', 'dhor' ),
						'slug'        => 'post-grid-elementor-addon',
					),
					array(
						'name'        => esc_html__( 'Majestic Before After Image', 'dhor' ),
						'description' => esc_html__( 'Elementor addon to show the comparison of two images with a draggable handle.', 'dhor' ),
						'slug'        => 'majestic-before-after-image',
					),
				),
			)
		);

		$obj->set_sidebar(
			array(
				'render_callback' => 'dhor_render_welcome_page_sidebar',
			)
		);

		$obj->run();
	}
);

/**
 * Render welcome page sidebar.
 *
 * @since 1.0.0
 *
 * @param Welcome $object Instance of Welcome class.
 */
function dhor_render_welcome_page_sidebar( $object ) {
	$object->render_sidebar_box(
		array(
			'title'        => esc_html__( 'Leave a Review', 'dhor' ),
			'content'      => $object->get_stars() . sprintf( esc_html__( 'Are you are enjoying %1$s? We would appreciate a review.', 'dhor' ), $object->get_name() ),
			'button_text'  => esc_html__( 'Submit Review', 'dhor' ),
			'button_url'   => 'https://wordpress.org/support/theme/dhor/reviews/#new-post',
			'button_class' => 'button',
		),
		$object
	);
	$object->render_sidebar_box(
		array(
			'title'        => esc_html__( 'Our Themes', 'dhor' ),
			'content' => '<ol><li><a href="https://wordpress.org/themes/nari/" target="_blank">Nari - Feminine WordPress Blog Theme</a></li><li><a href="https://wordpress.org/themes/dhor/" target="_blank">Dhor - Minimal WordPress Blog Theme</a></li><li><a href="https://wordpress.org/themes/hait/" target="_blank">Hait - Multipurpose WordPress Blog Theme</a></li></ol>',
		),
		$object
	);
}
